==> linuxconf-1.19.src.tar.gz: linuxconf-1.19/modules/redhat/redhat.pm <==
/* _dict.cc 01/02/1998 20.19.44 */
/* devinfo.cc 20/06/2000 13.32.28 */
PUBLIC CONFIG_FILE_DEVLIST::CONFIG_FILE_DEVLIST (void);
PUBLIC int CONFIG_FILE_DEVLIST::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_DEVLIST::extract (SSTREAM&ss);
/* filter.cc 09/06/2000 20.22.22 */
PRIVATE void CONFDB_REDHAT::reset_modified (void);
PUBLIC CONFDB_REDHAT::CONFDB_REDHAT (CONFDB *_orig);
PUBLIC CONFDB_REDHAT::~CONFDB_REDHAT (void);
PUBLIC void CONFDB_REDHAT::setcursys (const char *_subsys);
PUBLIC int CONFDB_REDHAT::save (PRIVILEGE *priv);
PRIVATE const char *CONFDB_REDHAT::getvalfromrh (RHLK *rh);
PRIVATE void CONFDB_REDHAT::updaterh (RHLK *rh, const char *val);
PUBLIC const char *CONFDB_REDHAT::getval (const char *prefix,
	 const char *key,
	 const char *defval);
PUBLIC int CONFDB_REDHAT::getall (const char *prefix,
	 const char *key,
	 SSTRINGS&lst,
	 bool copy);
PUBLIC void CONFDB_REDHAT::removeall (const char *prefix,
	 const char *key);
PUBLIC void CONFDB_REDHAT::add (const char *prefix,
	 const char *key,
	 const char *val);
PUBLIC int CONFDB_REDHAT::archive (SSTREAM&ss, const char *_sys);
PUBLIC int CONFDB_REDHAT::extract (SSTREAM&ss, const char *_sys);
/* pam.cc 12/01/1999 10.32.06 */
/* redhat.cc 06/01/2000 21.03.54 */
PUBLIC MODULE_redhat::MODULE_redhat (void);
PUBLIC int MODULE_redhat::dohtml (const char *key);
PUBLIC int MODULE_redhat::execmain (int argc, char *argv[]);
/* reduser.cc 15/03/2000 11.29.28 */
/* routes.cc 02/05/1998 22.26.56 */
/* sysv.cc 23/06/2000 00.28.28 */
PUBLIC SERVICE_SYSV_REDHAT::SERVICE_SYSV_REDHAT (const char *_name,
	 const char *_desc,
	 int _state,
	 bool states[7]);
PUBLIC int SERVICE_SYSV_REDHAT::control (SERVICE_OPER oper);
PUBLIC const char *SERVICE_SYSV_REDHAT::getrunstatus (void);
PUBLIC const char *SERVICE_SYSV_REDHAT::getconfstatus (void);
PUBLIC void SERVICE_SYSV_REDHAT::showstatus (void);
PUBLIC int SERVICE_SYSV_REDHAT::install_levels (void);
PRIVATE void SERVICE_SYSV_REDHAT::readinfo (SSTRINGS&desc,
	 char suggest_levels[7]);
PUBLIC int SERVICE_SYSV_REDHAT::edit (void);
PUBLIC CONFIG_FILE_SYSV::CONFIG_FILE_SYSV (void);
PUBLIC int CONFIG_FILE_SYSV::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_SYSV::extract (SSTREAM&ss);

==> linuxconf-1.21.src.tar.gz: linuxconf-1.21/modules/redhat/redhat.pm <==
/* _dict.cc 01/02/1998 20.19.44 */
/* devinfo.cc 20/06/2000 13.32.28 */
PUBLIC CONFIG_FILE_DEVLIST::CONFIG_FILE_DEVLIST (void);
PUBLIC int CONFIG_FILE_DEVLIST::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_DEVLIST::extract (SSTREAM&ss);
/* filter.cc 07/08/2000 11.27.36 */
PRIVATE void CONFDB_REDHAT::reset_modified (void);
PUBLIC CONFDB_REDHAT::CONFDB_REDHAT (CONFDB *_orig);
PUBLIC CONFDB_REDHAT::~CONFDB_REDHAT (void);
PUBLIC void CONFDB_REDHAT::setcursys (const char *_subsys);
PUBLIC int CONFDB_REDHAT::save (PRIVILEGE *priv);
PRIVATE const char *CONFDB_REDHAT::getvalfromrh (RHLK *rh);
PRIVATE void CONFDB_REDHAT::updaterh (RHLK *rh, const char *val);
PUBLIC const char *CONFDB_REDHAT::getval (const char *prefix,
	 const char *key,
	 const char *defval);
PUBLIC int CONFDB_REDHAT::getall (const char *prefix,
	 const char *key,
	 SSTRINGS&lst,
	 bool copy);
PUBLIC void CONFDB_REDHAT::removeall (const char *prefix,
	 const char *key);
PUBLIC void CONFDB_REDHAT::add (const char *prefix,
	 const char *key,
	 const char *val);
PUBLIC int CONFDB_REDHAT::archive (SSTREAM&ss, const char *_sys);
PUBLIC int CONFDB_REDHAT::extract (SSTREAM&ss, const char *_sys);
/* pam.cc 21/08/2000 22.36.34 */
/* redhat.cc 28/08/2000 18.14.24 */
PUBLIC MODULE_redhat::MODULE_redhat (void);
PUBLIC int MODULE_redhat::dohtml (const char *key);
PUBLIC int MODULE_redhat::execmain (int argc, char *argv[], bool);
/* reduser.cc 15/03/2000 11.29.28 */
/* routes.cc 07/08/2000 11.28.02 */
/* sysv.cc 23/06/2000 11.59.34 */
PUBLIC SERVICE_SYSV_REDHAT::SERVICE_SYSV_REDHAT (const char *_name,
	 const char *_desc,
	 int _state,
	 bool states[7]);
PUBLIC int SERVICE_SYSV_REDHAT::control (SERVICE_OPER oper);
PUBLIC const char *SERVICE_SYSV_REDHAT::getrunstatus (void);
PUBLIC const char *SERVICE_SYSV_REDHAT::getconfstatus (void);
PUBLIC void SERVICE_SYSV_REDHAT::showstatus (void);
PUBLIC int SERVICE_SYSV_REDHAT::install_levels (void);
PRIVATE void SERVICE_SYSV_REDHAT::readinfo (SSTRINGS&desc,
	 char suggest_levels[7]);
PUBLIC int SERVICE_SYSV_REDHAT::edit (void);
PUBLIC CONFIG_FILE_SYSV::CONFIG_FILE_SYSV (void);
PUBLIC int CONFIG_FILE_SYSV::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_SYSV::extract (SSTREAM&ss);
